==> foundry_platform_sdk-0.25.0.tar.gz: foundry_platform_sdk-0.25.0/foundry/v2/orchestration/models/_upstream_target.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import List
from typing import Literal
from typing import cast

import pydantic

from foundry.v2.orchestration.models._buildable_rid import BuildableRid
from foundry.v2.orchestration.models._upstream_target_dict import UpstreamTargetDict


class UpstreamTarget(pydantic.BaseModel):
    """Target the specified datasets along with all upstream datasets except the ignored datasets."""

    target_rids: List[BuildableRid] = pydantic.Field(alias="targetRids")
    """The target datasets."""

    ignored_rids: List[BuildableRid] = pydantic.Field(alias="ignoredRids")
    """The datasets to ignore when calculating the final set of dataset to build."""

    type: Literal["upstream"]

    model_config = {"extra": "allow"}

    def to_dict(self) -> UpstreamTargetDict:
        """Return the dictionary representation of the model using the field aliases."""
        return cast(UpstreamTargetDict, self.model_dump(by_alias=True, exclude_unset=True))

==> foundry_platform_sdk-0.43.0.tar.gz: foundry_platform_sdk-0.43.0/foundry/v2/orchestration/models/_upstream_target.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import List
from typing import Literal
from typing import cast

import pydantic

from foundry.v2.orchestration.models._buildable_rid import BuildableRid
from foundry.v2.orchestration.models._upstream_target_dict import UpstreamTargetDict


class UpstreamTarget(pydantic.BaseModel):
    """Target the specified datasets along with all upstream datasets except the ignored datasets."""

    target_rids: List[BuildableRid] = pydantic.Field(alias="targetRids")
    """The target datasets."""

    ignored_rids: List[BuildableRid] = pydantic.Field(alias="ignoredRids")
    """The datasets to ignore when calculating the final set of dataset to build."""

    type: Literal["upstream"] = "upstream"

    model_config = {"extra": "allow"}

    def to_dict(self) -> UpstreamTargetDict:
        """Return the dictionary representation of the model using the field aliases."""
        return cast(UpstreamTargetDict, self.model_dump(by_alias=True, exclude_unset=True))
